==> humhub-1.2.1.tar.gz: humhub-1.2.1/protected/humhub/modules/directory/messages/nb_no/base.php <==
<?php
return array (
  '<b>Nobody wrote something yet.</b><br>Make the beginning and post something...' => '<b>Ingen har skrevet noe enda.</b><br>Start ved og poste ett innlegg...',
  '<b>There are no profile posts yet!</b>' => '<b>Det er ingen profil poster enda!</b>',
  '<strong>Directory</strong> menu' => '<strong>Innholds</strong> meny',
  '<strong>Group</strong> members - {group}' => '<strong>Gruppe</strong> brukere - {group}',
  '<strong>Group</strong> stats' => '<strong>Gruppe</strong> statistikk',
  '<strong>Member</strong> Group Directory' => '<strong>Medlemmer</strong> Gruppe innhold',
  '<strong>Member</strong> directory' => '<strong>Bruker</strong> område',
  '<strong>Member</strong> stats' => '<strong>Bruker</strong> Statistikk',
  '<strong>New</strong> people' => '<strong>Nye</strong> Brukere',
  '<strong>New</strong> spaces' => '<strong>Nye</strong> Grupper',
  '<strong>Space</strong> directory' => '<strong>Område</strong> oversikt',
  '<strong>Space</strong> stats' => '<strong>Gruppe</strong> statistikk',
  'Average members' => 'Gjennomsnittlig antall påloggede',
  'Directory' => 'Innhold',
  'Follows somebody' => 'Noen som følger andre',
  'Groups' => 'Grupper',
  'Members' => 'Medlemmer',
  'Most members' => 'Flest medlemmer',
  'No members found!' => 'Ingen brukere funnet!',
  'No spaces found!' => 'Ingen grupper funnet',
  'Online right now' => 'Online akkurat nå',
  'Private spaces' => 'Private grupper',
  'Search' => 'Søk',
  'See all' => 'Se alt',
  'Send invite' => 'Send invitasjon',
  'Spaces' => 'Grupper',
  'This group has no members yet.' => 'Denne gruppen har ingen medlemmer.',
  'Top Group' => 'Mest besøkte',
  'Total groups' => 'Totalt antall grupper',
  'Total spaces' => 'Antall grupper totalt',
  'Total users' => 'Brukere totalt ',
  'User profile posts' => 'Bruker innlegg',
  'You are a member of this space' => 'Du er medlem av dette område',
  'search for members' => 'Søk etter brukere',
  'search for spaces' => 'Søk etter område',
  'show all members' => 'Vis alle medlemmer',
);

==> humhub-1.2.8.tar.gz: humhub-1.2.8/protected/humhub/modules/directory/messages/nb_no/base.php <==
<?php
return array (
  '<b>Nobody wrote something yet.</b><br>Make the beginning and post something...' => '<b>Ingen har skrevet noe enda.</b><br>Start ved og poste ett innlegg...',
  '<b>There are no profile posts yet!</b>' => '<b>Det er ingen profil poster enda!</b>',
  '<strong>Directory</strong> menu' => '<strong>Innholds</strong> meny',
  '<strong>Group</strong> members - {group}' => '<strong>Gruppe</strong> brukere - {group}',
  '<strong>Group</strong> stats' => '<strong>Gruppe</strong>statistikk',
  '<strong>Member</strong> Group Directory' => '<strong>Medlemmer</strong> Gruppe innhold',
  '<strong>Member</strong> directory' => '<strong>Brukerområde</strong>',
  '<strong>Member</strong> stats' => '<strong>Brukerstatistikk</strong>',
  '<strong>New</strong> people' => '<strong>Nye</strong> Brukere',
  '<strong>New</strong> spaces' => '<strong>Nye</strong> Grupper',
  '<strong>Space</strong> directory' => '<strong>Område</strong> oversikt',
  '<strong>Space</strong> stats' => '<strong>Gruppestatistikk</strong>',
  'Average members' => 'Gjennomsnittlig antall påloggede',
  'Directory' => 'Innhold',
  'Follows somebody' => 'Noen som følger andre',
  'Groups' => 'Grupper',
  'Members' => 'Medlemmer',
  'Most members' => 'Flest medlemmer',
  'No members found!' => 'Ingen brukere funnet!',
  'No spaces found!' => 'Ingen grupper funnet',
  'Online right now' => 'Online akkurat nå',
  'Private spaces' => 'Private grupper',
  'Search' => 'Søk',
  'See all' => 'Se alt',
  'Send invite' => 'Send invitasjon',
  'Spaces' => 'Grupper',
  'This group has no members yet.' => 'Denne gruppen har ingen medlemmer.',
  'Top Group' => 'Mest besøkte',
  'Total groups' => 'Totalt antall grupper',
  'Total spaces' => 'Antall grupper totalt',
  'Total users' => 'Brukere totalt ',
  'User profile posts' => 'Brukerinnlegg',
  'You are a member of this space' => 'Du er medlem av dette område',
  'search for members' => 'Søk etter brukere',
  'search for spaces' => 'Søk etter område',
  'show all members' => 'Vis alle medlemmer',
);
